@@ -6,7 +6,7 @@ use warnings;
 use experimental 'smartmatch';
 
 our $DATE = '2014-07-09'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $VERSION = '0.74'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -19,8 +19,8 @@ sub parse_getopt_long_opt_spec {
     my $optspec = shift;
     $optspec =~ qr/\A
                (?:--)?
-               (?P<name>[A-Za-z0-9_-]+|\?)
-               (?P<aliases> (?: \| (?:[A-Za-z0-9_-]+|\?) )*)?
+               (?P<name>[A-Za-z0-9_][A-Za-z0-9_-]*)
+               (?P<aliases> (?: \| (?:[^:|!+=:-][^:|!+=:]*) )*)?
                (?:
                    (?P<is_neg>!) |
                    (?P<is_inc>\+) |
@@ -75,7 +75,12 @@ sub parse_getopt_long_opt_spec {
 
     $res{normalized} = join(
         "",
-        join("|", sort @{ $res{opts} }),
+        join("|", sort {
+            # we sort but put alphanumeric option first
+            my $a_is_alpha = $a =~ /^[A-Za-z0-9]/ ? 1:0;
+            my $b_is_alpha = $b =~ /^[A-Za-z0-9]/ ? 1:0;
+            $b_is_alpha <=> $a_is_alpha || $a cmp $b;
+        } @{ $res{opts} }),
         ($res{is_neg} ? "!" : $res{is_inc} ? "+" : ""),
         ($res{type} ? ("=", $res{type}, $res{desttype},
                        (defined($res{max_vals}) ? (defined($res{min_vals}) ? "{$res{min_vals},$res{max_vals}}" : "{$res{max_vals}}") : ())) : ()),
@@ -128,7 +133,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.73 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2014-07-09.
+This document describes version 0.74 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2014-07-09.
 
 =head1 FUNCTIONS
 
